function[] = plotReconstruction(saveFile)
%% Plots the reconstruction with shaded percentiles

%%% Parameters
id = 'high_gong_-25';
years = 1:2000;

colorEdges = [.3 1];
percSpacing = 1;
percLimit = [5 95];

nLowpassYears = 31;
%%%

% Load the reconstruction and percentiles
percs = percLimit(1):percSpacing:percLimit(2);
[recon, ~, devPercs] = load.reconstruction(id, years, percs);

% Lowpass filter
low = da.lowpass(recon, nLowpassYears, true);
lowPercs = da.lowpass(recon+devPercs, nLowpassYears, true);

% New figure
figure('Position', [1.6667 199 1044 420]);
hold on

% Add the percentile shading
percentileShading(years, lowPercs, percs, colorEdges);

% Add the reconstruction and lowpass
plot(years, recon,'linewidth',1);
plot(years, low, 'k', 'linewidth', 3);

% Finalize
set(gca,'fontsize',21,'XColor', 'w');
xticks([]);

% set(gca,'fontsize',21);
% title('SAM Reconstruction');

xlim([0 2000]);
plot(xlim, [0 0], 'Color', 'k', 'linewidth', .75);
ylabel('SAM Index');
ylim([-6.5 5]);
yticks(-8:2:6);

% Save
if nargin>0
    print(saveFile, '-depsc', '-painters');
end

end