function[] = plotInstrumental(saveFile)

%%%%% Plot Parameters %%%%%
id = "high_gong_-25";
years = 1900:2000;
anomalyYears = 1958:2000;

percSpacing = 1;
percLimit = [5 95];
colorEdges = [.4 1];
%%%%%%%%%%%%%%%%%%%%%%%%%%%


% Percentiles
percs = percLimit(1):percSpacing:percLimit(2);
nPercs = numel(percs);

% Load the Marshall index and reconstruction
[marsh, mmeta] = gridfile('marshall-djf.grid').load;
[recon, ~, devPercs] = load.reconstruction(id, years, percs);

% Zscore over the instrumental period
M = da.anomalize(marsh, mmeta.time, anomalyYears);
[R, Xstd] = da.anomalize(recon, years, anomalyYears);
devPercs = devPercs ./ Xstd;

% Get the percentile edges
center = R + devPercs;
edges = movmean(center, 2, 2, 'Endpoints','discard');
percs([1 end]) = [];
nPercs = nPercs - 2;

% Percentile colors
dist = abs(percs-50);
color = interp1( [0 50], colorEdges, dist );

% Correlation
xyears = intersect(years, mmeta.time);
useR = ismember(years, xyears);
useM = ismember(mmeta.time, xyears);
[rho, pval] = corr(R(useR), M(useM));
pval = round(pval, abs(ceil(log10(pval))));

% Create figure
figure('Position', [1.6667 199 1044 420]);
hold on

% Percentile patches
xs = [years, fliplr(years)];
for p = 1:nPercs
    ys = [edges(:,p); flipud(edges(:,p+1))];
    C = color(p) * [1 1 1];
    patch(xs, ys, C, 'Edgecolor', C);
end

% Time series
p1 = plot(years, R, 'linewidth', 3);
p2 = plot(mmeta.time, M, 'linewidth', 3);

% Correlation legend
p3 =  plot(NaN, NaN, 'w');
p4 = plot(NaN, NaN, 'w');
legstr = sprintf('r = %0.2f  (p << 0.001)', rho);
legend([p2, p3, p1, p4], "Marshall Index", "", "Reconstruction", legstr, ...
        'NumColumns', 2, 'Location', 'northwest');
leg = legend('boxoff');
leg.Position = [0.1520    0.8036    0.3570    0.1123];

% Finalize
xlim([years(1), years(end)]);
plot(xlim, [0 0], 'Color', 'k', 'linewidth', .75);
set(gca,'fontsize',21, 'Box', 'off');
ylim([-6 6]);
xticks(1900:25:2000);
yticks(-6:3:6);
ylabel("SAM Index");
xlabel("Year (CE)");

if nargin>0
    print(saveFile,'-depsc','-painters');
end

end