function[] = sensorBars(saveFile)

% Parameters
calFactor = 1.14;
width = 9.87;
height = 3.5;
id = "high_gong_-25";
widthBuffer = 0.075;
axBuffer = 0.01;
axHeight = 0.74;
heightBuffer = 0.24;
ylim1 = [0 30];
ylim2 = [0 30];
yticklocs = {0:3:9, 0:3:9, 0:10:30};

%%% For equal axis
ylim1 = [0 9];
axBuffer = 0.04;
%%%


years = [8, 1399, 1850];
titles = ["8 - 165 CE", "1232 - 1399 CE", "1848 - 1983 CE"];
maxSites = 5;

% Load the sensor data, site metadata, and atlas block updates
sensor = load(sprintf('sensor-%s', id));
ids = da.siteNames(sensor.networks, sensor.meta);
anzda = load(sprintf('anzda_1600-%s', id));
sada = load(sprintf('sada_1600-%s', id));

% Get the SADA and ANZDA potential variance
sadaVar = 100 * (1 - sada.Avar / sensor.iVar);
anzdaVar = 100 * (1 - anzda.Avar / sensor.iVar);

% Preallocate
vars = NaN(maxSites, 3);
names = strings(maxSites, 3);

% Get PAGES variances and site names for each proxy set
p = 1:size(sensor.meta{sensor.networks=="pages"}.coord, 1);
for y = 1:numel(years)
    proxySet = sensor.whichSet(years(y));
    obs = sensor.sites(p, proxySet);
    percVar = sensor.potentialVar(obs, proxySet);
    siteNames = ids(obs);
    
    % Add in the SADA and ANZDA block updates for the last set of years
    if y == numel(years)
        percVar = [percVar; anzdaVar; sadaVar]; %#ok<AGROW>
        siteNames = [siteNames; "ANZDA"; "SADA"]; %#ok<AGROW>
    end
    
    % Sort the sites by potential variance
    [percVar, k] = sort(percVar);
    siteNames = siteNames(k);
    
    % Retain the top sites
    nSite = numel(siteNames);
    use = nSite-min(maxSites,nSite)+1:nSite;
    nKeep = numel(use);
    vars(1:nKeep, y) = percVar(use);
    names(1:nKeep, y) = siteNames(use);
end

% Format names
k = names == "Site DML17";
names(k) = "DML17";
    
% New figure
figure('Position', [1 1 1080.1728 383.04]);

% Bar plot axes
axWidth = (1 - 2*widthBuffer - 2*axBuffer) / 3;
ax1 = axes('Position', [widthBuffer heightBuffer axWidth axHeight]);
ax2 = axes('Position', [widthBuffer+axWidth+axBuffer, heightBuffer, axWidth, axHeight]);
ax3 = axes('Position', [widthBuffer+2*axWidth+2*axBuffer, heightBuffer, axWidth, axHeight]);
axs = [ax1, ax2, ax3];

% Do each plot
for k = 1:3
    axes(axs(k)); %#ok<LAXES>
    N = sum(~isnan(vars(:,k)));
    bar(vars(1:N,k));
    xticks(1:N);
    xticklabels(names(1:N,k));
    set(gca,'XTickLabelRotation', 40, 'fontsize',22, 'TickDir', 'out', 'box', 'off');
    t = title(titles(k), 'Fontsize',22, 'VerticalAlignment', 'top');
    yticks(yticklocs{k});
    
    % Y limit adjustments
    if k~=3
        ylim(ylim1);
        drop = 0.16;
    else
        ylim(ylim2);
        drop = 0.53;
    end
    pause(.01);
    t.Position(2) = t.Position(2) - drop;
    
    % Add Y label
    if k==1
        ylab = ylabel(sprintf('Percent Variance\nConstrained'));
        set(ylab, 'Fontsize',22);
    end
end


%% Adjust figure labels

fig = gcf;
ax1 = fig.Children(3);
ax2 = fig.Children(2);
ax3 = fig.Children(1);

ax1.Units = 'pixels';
ax2.Units = 'pixels';
ax3.Units = 'pixels';

bottom = ax1.Position(2);
addToHeight = 90;
drop = 10;

fig.Position(4) = fig.Position(4)+addToHeight;
ax1.Position(2) = bottom + addToHeight - drop;
ax2.Position(2) = bottom + addToHeight -drop;
ax3.Position(2) = bottom + addToHeight-drop;

left1 = ax1.Position(1);
left2 = ax2.Position(1);
left3 = ax3.Position(1);

addToLeft = 30;
fig.Position(3) = fig.Position(3) + addToLeft;
ax1.Position(1) = left1 + addToLeft;
ax2.Position(1) = left2 + addToLeft;
ax3.Position(1) = left3 + addToLeft;

% Save
if nargin>0
    print(saveFile, '-depsc', '-painters');
end

end






