function[] = sensorMap(saveFile)


%%% Parameters
id = "high_gong_-25";
pagesSizeLimits = [150 500];
clim = [0 9];
%%%

%% Collect variances

% Load the sensor data and site metadata
sensor = load(sprintf('sensor-%s', id));
names = da.siteNames(sensor.networks, sensor.meta);

% Get the variances for each network
full = find( all(sensor.sites, 1) );
vars = sensor.potentialVar(:, full);

issada = names=="sada";
isanzda = names=="anzda";
ispages = ~issada & ~isanzda;

pvar = vars(ispages);
avar = vars(isanzda);
svar = vars(issada);

% Sort the metadata for each network
pmeta = sensor.meta{sensor.networks=="pages"};
ameta = sensor.meta{sensor.networks=="anzda"};
smeta = sensor.meta{sensor.networks=="sada"};

% Convert drought atlases from coordinate array to cartesian grid
downgrid = spatialGrid.DA([sensor.priors, sensor.reanalysis]);
anzda = spatialGrid.atlas("anzda");
sada = spatialGrid.atlas("sada");

anzda = downgrid.surround(anzda);
sada = downgrid.surround(sada);

avar = anzda.regrid(avar, ameta.coord);
svar = sada.regrid(svar, smeta.coord);


%% Drought Atlases

% New figure
figure('Position', [0 0 1144.66 500]);
m_proj('stereo', 'lat', -90, 'lon', -120, 'rad', 90-25);
subplot(1,2,1);
hold on

% Plot the atlases
m_pcolor(sada.lon, sada.lat, svar);
m_pcolor(anzda.lon, anzda.lat, avar);
m_coast;
m_grid('XaxisLocation', 'top', 'YaxisLocation', 'middle', 'fontsize',22, 'ytick', [-90 -60 -40])

% Set the colormap
% cbar = colorbar;
% clab = cbar.Label;
% clab.String = "Potential Percent Constrained Variance";
% clab.Rotation = 270;
% clab.VerticalAlignment = 'bottom';
cmap = cbrew('redblue', 16*2, true);
cmap = cmap(17:end,:);
colormap(cmap);
set(gca,'clim', clim, 'fontsize',22);


%% PAGES

% New axis
subplot(1,2,2);
hold on

% Get the icons and size
icon = pagesMarkers(pmeta.attributes.type);
varLimit = [min(pvar), max(pvar)];
iconSize = interp1(varLimit, pagesSizeLimits, pvar);

% Sort by size
[iconSize, sorted] = sort(iconSize, 'descend');
pmeta.coord = pmeta.coord(sorted, :);
pvar = pvar(sorted);
icon = icon(sorted);

% Plot
m_coast;
for p = 1:numel(pvar)
    m_scatter(pmeta.coord(p,2), pmeta.coord(p,1), iconSize(p), pvar(p), ...
        icon(p), 'filled', 'MarkerEdgeColor', 'k');
end
m_grid('XaxisLocation', 'top', 'YaxisLocation', 'middle', 'fontsize',22,'ytick',[-90 -60 -40])

% Colormap
% cbar = colorbar;
% clab = cbar.Label;
% clab.String = "Potential Percent Constrained Variance";
% clab.Rotation = 270;
% clab.VerticalAlignment = 'bottom';
colormap(cmap);
set(gca,'clim', clim, 'fontsize',18);


%% Adjust font scaling

fig = gcf;
ax1 = fig.Children(2);
ax2 = fig.Children(1);
ax3 = axes('Position', [0 0 0 0]);

ax1.Units = 'pixels';
ax2.Units = 'pixels';
ax3.Units = 'pixels';

ax1.Position(3:4) = 410;
ax2.Position(3:4) = 410;

moveLeft = 45;

ax1.Position(1) = 75-moveLeft;
ax2.Position(1) = 550-moveLeft;

cbar = colorbar('Units','pixels', 'position', [1015-moveLeft       56       21.333       410], 'fontsize',24);
clab = cbar.Label;
clab.String = sprintf("Percent Variance Constrained");
clab.Rotation = 270;
clab.VerticalAlignment = 'bottom';

fig.Position(3) = 1065;
set(ax3,'clim', [0 9]);
set(cbar, 'Ticks', 0:3:9);

% Save
if nargin>0
    print(saveFile, '-depsc','-painters');
end
end