function[] = plotSEA(saveFig)
%% Plots the results of the SEA analysis


%%%%% Parameters %%%%%
id = "high_gong_-25";
volcSet = "last2k";
CI = .95;
percs = 5:95;
%%%%%%%%%%%%%%%%%%%%%%

% Default
if ~exist('saveFig','var') || isempty(saveFig)
    saveFig = false;
end

% Load the sea analysis
file = sprintf('sea-%s-%s', volcSet, id);
out = load(file);
years = out.returnYears(:);
MC = size(out.noise,2);

% Get SEA and the percentiles for the uncertainty bound
sea = mean(out.events, 2);
seaPercs = prctile(out.noise, percs, 2);

% % Get the indices of the confidence interval
% step = (1-CI)/2;
% upper = ceil( (1-step)*MC );
% lower = floor( step*MC );
% 
% % Get the sea and uncertainty bounds
% upperBound = out.noise(:,upper);
% lowerBound = out.noise(:,lower);

% New figure
% figure('Position', [0 0 886 639.3333/2]);
figure('Position', [361 159.6667 598 459.3333])
hold on

% Plot shaded percentiles and SEA
percentileShading(years, seaPercs, percs);
plot(years, sea, 'linewidth', 2.5);



% % % Get patch data
% % xs = [years; flipud(years)];
% % ys = [upperBound; flipud(lowerBound)];
% % 
% % % Plot
% % pci = patch(xs, ys, [.75 .75 .75], 'Edgecolor', 'none');
% % ps = 
% % % plot(years, out.events, 'color', [.5 .5 .5], 'linewidth', .00001);

% Finalize
ylabel("SAM Anomaly");
xlabel("Year after Eruption");
set(gca, 'fontsize', 14);
xlim([-5 10]);
% ylim([-3 3]);

% Add dotted lines at zeros
xlimit = get(gca,'xlim');
ylimit = get(gca,'ylim');
plot(xlimit, [0 0], 'k:');
plot([0 0], ylimit, 'k:');
ylim(ylimit);

% Save
if saveFig
    print(saveFig,'-depsc','-painters');
end

end