function[] = compareReconstructions(saveFile)

%%%%%%%
colors = [...
  0.0  0.2716  1.0000   % A14
  0.5031  0.5598  0.9882   % V12
  0.5843  0.8157  0.9882]; % D18

anomalyYears = 1400:1850;
reconID = "high_gong_-25";
reconYears = 1000:2000;
%%%%%%

% Load the reconstructions
[A14, Ameta] = gridfile('abram-2014.grid').load;
[V12, Vmeta] = gridfile('villalba-2012.grid').load;
[D18, Dmeta] = gridfile('datwyler-2018.grid').load;
recon = load.reconstruction(reconID, reconYears);

% Get years
Ayears = Ameta.time;
Vyears = Vmeta.time;
Dyears = Dmeta.time;

% Remove post-2000
[A14, Ayears] = removeYears(A14, Ayears);
[V12, Vyears] = removeYears(V12, Vyears);
[D18, Dyears] = removeYears(D18, Dyears);

% Normalize
A14 = normalize(A14, Ayears, anomalyYears);
V12 = normalize(V12, Vyears, anomalyYears);
D18 = normalize(D18, Dyears, anomalyYears);
recon = normalize(recon, reconYears, anomalyYears);


% Plot
figure('Position', [1 1 1280 643]);
axes('Units','centimeters', 'Position', [2.1967 9.876 13.096 4.6333]);

hold on;lwx = 2;
[~,indx,~] = intersect(Ayears,anomalyYears);
px1 = plot(Ayears,gaussiansmooth(A14-mean(A14(indx),'omitnan'),30,'mean'),'color',colors(1,:),'linewidth',lwx);
[~,indx,~] = intersect(Vyears,anomalyYears);
px2 = plot(Vyears,gaussiansmooth(V12-mean(V12(indx),'omitnan'),30,'mean'),'color',colors(2,:),'linewidth',lwx);
[~,indx,~] = intersect(Dyears,anomalyYears);
px3 = plot(Dyears,gaussiansmooth(D18-mean(D18(indx),'omitnan'),30,'mean'),'color',colors(3,:),'linewidth',lwx);
[~,indx,~] = intersect(reconYears,anomalyYears);
px4 = plot(reconYears,gaussiansmooth(recon-mean(recon(indx),'omitnan'),30,'mean'),'color','r','linewidth',lwx);
legend([px4 px1 px2 px3],'This Study','A14','V12','D18','location','northoutside','Orientation','horizontal');
legend boxoff
set(gca,'XMinorTick','on','YMinorTick','on','box','on','fontsize',12)
ylabel('SAM Index Anomaly')
xlabel('Year')
xlim([1000 2000])
ylim([-2 3])

% Save to eps
if nargin>0
    print(saveFile, '-depsc','-painters');
end

end

%% Utilities
function[X] = normalize(X, years, anomalyYears)
baseline = ismember(years, anomalyYears);
Xmean = mean(X(baseline));
Xstd = std(X(baseline));
X = (X - Xmean) / Xstd;
end
function[X, years] = removeYears(X, years)
remove = years > 2000;
X(remove) = [];
years(remove) = [];
end