function[] = plotTrendsEarlyCI(marshallFile, reconFile)


% Load
early = load('trend-early-95-high_gong_-25.mat');

% Zero pad significance
edges = false(1, numel(early.trendYears));
early.rsig = cat(1, edges, early.rsig, edges);
rWindows = [early.reconWindows(1)-2, early.reconWindows, early.reconWindows(end)+2];

edges = false(1, numel(early.marshallYears));
early.msig = cat(1, edges, early.msig, edges);
mWindows = [early.marshallWindows(1)-2, early.marshallWindows, early.marshallWindows(end)+2];

% Plot reconstruction trends
figure('Position', [361 159.6667 598 459.3333]);
imagesc(early.trendYears, early.reconWindows, early.rtrends);
set(gca, 'ydir','normal');
xlim([1914.5, 1985.5])
scaleColorMap(cbrew('redblue',20,true), 0, gca, [-.1 .1]);
% colorbar('Position', [0.8339 0.1234 0.0357 0.8012]); 
initialCmap = colormap(gca);
cmap = [.75 .75 .75; initialCmap];
colormap(cmap);
clim = get(gca,'clim');
nColors = size(cmap,1)-1;
step = (clim(2)-clim(1))/nColors;
newClim = [clim(1)-step, clim(2)];
set(gca, 'clim', newClim, 'fontsize',14,'position',[0.1172 0.1239 0.6989 0.8011]);
ylabel('Trend Length (years)');
xlabel('Year (CE)');
hold on
[~,c1] = contour(early.trendYears, rWindows, early.rsig, 1, 'k', 'linewidth', .75);
title('Reconstruction');
legend(c1, ' 0001-0899 CE', 'position', [0.5412 0.8218 0.2748 0.1027]);
% ax = gca;
% ax.Units = 'pixels';
% ax.Position = [67.9067 58.2667 386.8000 331.2333];
ax = axes('position',[0 0 0 0]);
set(ax, 'clim', [-.1 .1]);
colormap(ax, initialCmap);
cbar = colorbar('position', [0.8339 0.1234 0.0357 0.8012],'fontsize',14,'ticks',-.1:.05:.1);
clab = cbar.Label;
clab.String = 'Normalized Trend';
clab.Rotation = 270;
clab.VerticalAlignment = 'bottom';

if nargin>1
    print(reconFile, '-depsc', '-painters');
end

% Plot Marshall trends
figure('Position', [361 159.6667 598 459.3333]);
imagesc(early.marshallYears, early.marshallWindows, early.mtrends);
set(gca, 'ydir','normal');
xlim([1972.5, 2005.5])
scaleColorMap(cbrew('redblue',20,true), 0, []);
% colorbar('Position', [0.8339 0.1234 0.0357 0.8012]); 
cmap = colormap(gca);
cmap = [.75 .75 .75; cmap];
colormap(cmap);
clim = get(gca,'clim');
nColors = size(cmap,1)-1;
step = (clim(2)-clim(1))/nColors;
newClim = [clim(1)-step, clim(2)];
set(gca, 'clim', newClim, 'fontsize',14,'position',[0.1172 0.1239 0.6989 0.8011]);
ylabel('Trend Length (years)');
xlabel('Year (CE)');
hold on
[~,c1] = contour(early.marshallYears, mWindows, early.msig, 1, 'k', 'linewidth', 1);
title('Marshall Index');
legend(c1, ' 0001-0899 CE', 'position', [0.5412 0.8218 0.2748 0.1027]);
% ax = gca;
% ax.Units = 'pixels';
% ax.Position = [67.9067 58.2667 386.8000 331.2333];
ax = axes('position',[0 0 0 0]);
set(ax, 'clim', [-.1 .1]);
colormap(ax, initialCmap);
cbar = colorbar('position', [0.8339 0.1234 0.0357 0.8012],'fontsize',14,'ticks',-.1:.05:.1);
clab = cbar.Label;
clab.String = 'Trend';
clab.Rotation = 270;
clab.VerticalAlignment = 'bottom';

if nargin>0
    print(marshallFile, '-depsc','-painters');
end

end