function[] = plotLatitudeTests(saveFile)

% Parameters
testLats = -50:30;
compareYears = 1958:2000;

% Load the marshall index
[marshall, mmeta] = gridfile('marshall-djf.grid').load;
use = ismember(mmeta.time, compareYears);
marshall = marshall(use);
mmeta.time = mmeta.time(use);

% Preallocate
nLat = numel(testLats);
rFull = NaN(nLat, 1);
rHigh = NaN(nLat, 1);

% Check the correlation of each reconstruction
for k = 1:numel(testLats)
    fullID = sprintf('all_gong_%+03.f', testLats(k));
    highID = sprintf('high_gong_%+03.f', testLats(k));
    
    full = load.reconstruction(fullID, 1958:2000);
    high = load.reconstruction(highID, 1958:2000);
    
    rFull(k) = corr(marshall, full);
    rHigh(k) = corr(marshall, high);
end

% Plot
figure
hold on
p1 = plot(testLats, rFull, 'linewidth', 1);
p2 = plot(testLats, rHigh, 'linewidth', 1);
legend('All models','High-Resolution','location','southeast');
ylabel('Correlation with Marshall Index');
xlabel('Northern Latitude Boundary');
set(gca,'fontsize',16);

% Save
if nargin>0
    print(saveFile, '-depsc', '-painters');
end

end