function[] = priorSkill(saveFile)

% Load the assimilations
samAll = load.assimilation('all_gong_-25', 1958:2000);
samHigh = load.assimilation('high_gong_-25', 1958:2000);

% Load the Marshall index
marsh = gridfile('marshall-djf.grid');
inst = marsh.meta.time<=2000;
[marsh, mmeta] = marsh.load("time",{inst});

% Scale detrended mean and variance
[allMean, allStd] = da.detrendedScalingFactors(marsh, samAll);
samAll = (samAll - allMean) / allStd;

[highMean, highStd] = da.detrendedScalingFactors(marsh, samHigh);
samHigh = (samHigh - highMean) / highStd;

% Preallocate
rho = NaN(2,1);
rmse = NaN(2,1);
ratio = NaN(2,1);
bias = NaN(2,1);

% Get metrics
rho(1) = corr(samAll, marsh);
rho(2) = corr(samHigh, marsh);

rmse(1) = sqrt(mean((samAll-marsh).^2));
rmse(2) = sqrt(mean((samHigh-marsh).^2));

ratio(1) = std(samAll) ./ std(marsh);
ratio(2) = std(samHigh) ./ std(marsh);

bias(1) = mean(samAll) - mean(marsh);
bias(2) = mean(samHigh) - mean(marsh);

% Plot
red = [ 0.85   0.325   0.098];
figure('Position', [3 198 917 420]);
hold on
plot(1:4, [rho(1),rmse(1),ratio(1),-bias(1)], 'ko', 'markersize',10,'markerfacecolor','k');
plot(1:4, [rho(2),rmse(2),ratio(2),-bias(2)], 'v', 'markersize',10,'color',red,'markerfacecolor',red);
xlim([0.5 4.5]);
xticks(1:4);
xticklabels(["Correlation","RMSE","\sigma Ratio","-(Mean Bias)"]);
ylim([0 2]);
ylabel('Skill Value');
set(gca,'fontsize',18);
legend("All model MME","High-resolution MME");

% Save
if nargin>0
    print(saveFile, '-depsc', '-painters');
end

end