function[] = plotVarianceAdjustment(rawFile, stdFile, weightFile)


id = "high_gong_-25";
years = 1:2000;
raw = load.assimilation(id, years);
recon = load.reconstruction(id, years);

figure('Position', [1.6667 199 1044 420]);
p1 = plot(years, recon);
hold on
p2 = plot(years, raw);
legend([p2 p1], 'Raw', 'Adjusted','NumColumns',2);
ylabel('SAM Index');
xlabel('Year (CE)');
set(gca,'fontsize',18);

if nargin>0
    print(rawFile,'-depsc','-painters');
end

msraw = movstd(raw,30,'Endpoints','fill');
msrecon = movstd(recon,30,'Endpoints','fill');
use = ~isnan(msraw);
craw = polyfit(years(use), msraw(use), 1);
crecon = polyfit(years(use), msrecon(use), 1);

colors = colororder;
figure('Position', [1.6667 199 1044 420]);
hold on
p1 = plot(years, msrecon, 'color', colors(1,:));
p2 = plot(years, msraw, 'color', colors(2,:));
t1 = plot(years, years*crecon(1)+crecon(2), ':', 'color', colors(1,:), 'linewidth', 1.5);
t2 = plot(years, years*craw(1)+craw(2), ':','color', colors(2,:), 'linewidth', 1.5);
name1 = sprintf('       Raw: %.2f units / millennium', 1000*craw(1));
name2 = sprintf('Adjusted: %.2f units / millennium', 1000*crecon(1));
legend([p2, t2, p1, t1], 'Raw', sprintf('%.2f units / millennium',1000*craw(1)), 'Adjusted', sprintf('%.2f units / millennium', 1000*crecon(1)),...
    'NumColumns', 2);
set(gca,'fontsize',18);
ylabel(sprintf('Standard Deviation\n(30-year window)'));
xlabel('Year (CE)');

if nargin>1
    print(stdFile,'-depsc','-painters');
end

figure('Position', [1.6667 199 1044 420]);
w = da.weights(id, years);
plot(years, w, 'linewidth', 1.5);
ylabel('Scaling weight');
xlabel('Year (CE)');
set(gca,'fontsize',18);

if nargin>2
    print(weightFile,'-depsc','-painters');
end

end