function[rho, pval] = D21statistics
%% D21statistics  Computes correlation and p-value of D21 with the Marshall index
% ----------
%   [rho, pval] = D21statistics
%   Returns correlations and p-values for the Dalaiden et al., 2021 
%   reconstruction. (D21 reports skill on a different time interval than
%   this study. We recalculate statistics on our own time interval to
%   enable a fair comparison.) Reported p-values use an effective sample
%   size accounting for AR1.
% ----------
%   Outputs:
%       rho (numeric scalar): Correlation with the Marshall index
%       pval (numeric scalar): AR1 adjusted p-value

% Get the reconstructions and Marshall index
d21 = gridfile('dalaiden-2021.grid');
marsh = gridfile('marshall-djf.grid');

% Limit to skill interval
years = parameters.years.skill;
dYears = ismember(d21.metadata.time, years);
mYears = ismember(marsh.metadata.time, years);

% Load the reconstruction and marshall index
d21 = d21.load("time", {dYears});
marsh = marsh.load("time", {mYears});

% Get the correlation and AR1 adjusted pvalues
[rho, pval] = brethertonCorr(d21, marsh);

end