function[] = reconstructionSkill

%%% Parameters
id = "high_gong_-25";
normYears = 1958:2000;
fogtYears = 1900:2000;
%%%

% Get the scaling factors for fogt and reconstruction
mgrid = gridfile('marshall-djf.grid');
fgrid = gridfile('fogt-djf.grid');

time = ismember( mgrid.meta.time, normYears );
marsh = mgrid.load("time", {time});
time = ismember( fgrid.meta.time, normYears );
fogt = fgrid.load("time", {time});
recon = load.reconstruction(id, normYears);

[fmean, fstd] = da.detrendedScalingFactors(marsh, fogt);
[rmean, rstd] = da.detrendedScalingFactors(marsh, recon);

% Load Fogt and reconstruction. Scale to Marshall index
time = ismember(fgrid.meta.time, fogtYears );
fogt = fgrid.load("time", {time});
recon = load.reconstruction(id, fogtYears);

fogt = (fogt - fmean) / fstd;
recon = (recon - rmean) / rstd;

% Preallocate
rho = NaN(3,1);
pval = NaN(3,1);
rmse = NaN(3,1);
ratio = NaN(3,1);
bias = NaN(3,1);

% Get skill metrics
inst = ismember(fogtYears, normYears);
ts = {[marsh, recon(inst)], [fogt(inst), recon(inst)], [fogt, recon]};
for t = 1:numel(ts)
    ts1 = ts{t}(:,1);
    ts2 = ts{t}(:,2);
    
    rmse(t) = sqrt(mean((ts1-ts2).^2));
    ratio(t) = std(ts2) / std(ts1);
    bias(t) = mean(ts2) - mean(ts1);
    [rho(t), pval(t)] = brethertonCorr(ts1, ts2);
end

% Build the latex table
assert(all(pval<1E-4), 'Not all p-values are less than 1E-4');
fprintf('\n');
fprintf('Correlation ($p\\ll0.01$)& %.2f & %.2f & %.2f \\\\ \n', rho);
fprintf('RMSE & %.2f & %.2f & %.2f \\\\ \n', rmse);
fprintf('$\\sigma$ Ratio & %.2f & %.2f & %.2f \\\\ \n', ratio);
fprintf('Mean Bias & %.2f & %.2f & %.2f \\\\ \n', bias);

end