function[lats, r] = modelSAMLatitudes(models)
%% modelSAMLatitudes  Determines the latitudes matching the SAM definition for different climate model outputs
% ----------
%   [lats, r] = modelSAMLatitudes(models)

% Preallocate
nModel = numel(models);
lats = NaN(nModel, 2);
r = NaN(nModel, 1);

% Build a zonal-mean, DJF state vector for each model
for m = 1:nModel
    file = sprintf('slp-%s.grid', models(m));
    meta = gridfile(file).meta;
    sh = meta.lat<-20;
    dec = month(meta.time)==12;

    sv = stateVector;
    sv = sv.add('SLP', file);
    sv = sv.design('SLP', ["lat","time"], [true,false], {sh,dec});
    sv = sv.mean('SLP', ["lon","time"], {[], 0:2});
    [~,info] = sv.info(1);
    N = info.possibleMembers;
    [X, ensMeta] = sv.build(N);
    
    % Find the latitudes with strongest anticorrelation
    svlats = ensMeta.dimension('lat');
    rhos = corr(X', 'rows', 'complete');
    [r(m), ind] = min(rhos, [], 'all', 'linear');
    ind = ind(1);
    [row, col] = ind2sub(size(rhos), ind);
    lats(m,:) = svlats([row, col]);
    lats(m,:) = sort(lats(m,:),'descend');
end
lats = -lats;

% Build the latex table
fprintf('\n');
for m = 1:nModel
    fprintf('%s & %.f\\degree S, %.f\\degree S & %.2f \\\\ \n', ...
        upper(models(m)), lats(m,1), lats(m,2), r(m));
end

end