function[icons, markers] = pagesMarkers(types)
%% Returns markers for PAGES proxy types
%
% icon = pagesMarkers(types)
%
% ----- Inputs -----
%
% types: A list of PAGES proxy types
%
% ----- Outputs -----
%
% icon: The plot icon for each type

% Settings
markers = {"tree", "v";...
           "coral", "d";...
           "lake sediment", "s";...
           ["glacier ice","borehole"], "o"};

% Preallocate
nSite = numel(types);
icons = strings(nSite, 1);

% Get each marker type
for m = 1:size(markers,1)
    icons(ismember(types, markers{m,1})) = markers{m,2};
end

% Check all types have icons
if any(strcmp(icons, ""))
    bad = find(icons=="", 1);
    error('Proxy type %.f is not a recognized type', bad);
end

end