function[] = percentileShading(x, tsPercs, percs, greyLimits)
%% Plots patches for percentile shading
%
% percentileShading(x, tsPercs, percs)
% Plots shaded percentile patches
%
% percentileShading(x, tsPercs, percs, greyLimits)
% Also set the limits of the grey color scale
%
% ----- Inputs -----
%
% x: The x axis data points spanned by the shaded time series percentiles
%
% tsPercs: The percentiles of a time series. (nTime x nPercs)
%
% percs: The percentile associated with each time series
%
% greyLimits: Two elements. First is outside (light) grey, second in inside
%    (dark) grey. If unspecified uses [.3 1]

% Default
if ~exist('greyLimits','var') || isempty(greyLimits)
    greyLimits = [.3 1];
end

% Get the edges of each shading patch
edges = movmean(tsPercs, 2, 2, 'Endpoints', 'discard');
percs([1 end]) = [];
nPercs = numel(percs);

% Get the color of each percentile band
dist = abs(percs - 50);
color = interp1( [0 50], greyLimits, dist );

% Get the x points
x = x(:);
xs = [x; flipud(x)];

% Get the current hold state and set hold on
holdOn = true;
if ~ishold
    holdOn = false;
    hold on;
end

% Plot each patch
for p = 1:nPercs
    ys = [edges(:,p); flipud(edges(:,p+1))];
    C = color(p) * [1 1 1];
    patch(xs, ys, C, 'edgecolor', C);
end

% Restore hold state
if ~holdOn
    hold off
end

end