%% figuresAndTables  
% 
% This script demonstrates how to call the functions used to generate the
% figures and tables for the analysis. The script is broken into sections,
% and each section corresponds to a particular figure or table.
%
% Before running any of the functions shown here, you will need to:
%   
%   1. Download the "Analysis" folder from the repository, and
%   2. Add "Analysis" and all its subfolders to the active Matlab path. 
%      You can do this by right-clicking the "Analysis" folder in the
%      Matlab editor, and then selecting the 
%      "Add to Path"->"Selected Folder and Subfolders" option.
%
% The function for Supplemental Table 2 also requires some of the raw 
% climate model output to run. Details on implementing this are provided
% in that section of this script.

%% Figure 1: Proxy network map

networkMap('network-map-initial.eps');

% Initial figure edited in Adobe Illustrator CC 2021 to produce final
% figure 'network-map-edited.eps'

%% Figure 2: Reconstruction time series

% A. Instrumental, B. Full reconstruction, C. Sample depth
plotInstrumental('instrumental.eps');
plotReconstruction('full-reconstruction.eps');
sampleDepth('sample-depth.eps');

% Subplots merged and edited in Adobe Illustrator CC 2021
% to produce final figure 'time-series.eps'

%% Figure 3: Optimal sensor analysis

% A. Maps of proxy influence
% B. Time series of constrained variance
% C. Bar graphs of proxy influence
sensorMap('sensor-map.eps');
sensorTime('sensor-time.eps');
sensorBars('sensor-bar.eps');

% Subplots merged and edited in Adobe Illustrator CC 2021
% to produce final figure 'sensor.eps'

%% Figure 4: External climate forcing analysis

% A. Solar wavelet
% B. Volcanic SEA
% C. Modern Trend
plotSolarWavelet('solar-wavelet.eps');
plotSEA('sea.eps');
plotTrends('marshall-trends.eps', 'reconstruction-trends.eps');

% Subplots merged and edited in Adobe Illustrator CC 2021
% to produce final figure 'climate.eps'

%% Figure 5: Reconstruction comparison

compareReconstructions('reconstruction-comparison-initial.eps');

% Initial figure edited in Adobe Illustrator CC 2021 to produce final
% figure 'reconstruction-comparison-edited.eps'

%% Table 1: Reconstruction skill

reconstructionSkill;  % Prints Latex table to console


%% Inline statistics

[rho, pval] = D21statistics;
[rhos, pvals, priors] = O21statistics;


%% Supp. Figure 1: Trend analysis with early period confidence interval

plotTrendsEarlyCI("marshall-trends-early-ci.eps", 'reconstruction-trends-early-ci.eps');

% Subplots merged and edited in Adobe Illustrator CC 2021
% to produce final figure 'trend-early-ci.eps'


%% Supp. Figure 2: Latitude Cutoff Tests

plotLatitudeTests('network-cutoff.eps');


%% Supp. Figure 3:

priorSkill('prior-skill.eps');


%% Supp. Figure 4:

% A. Raw and adjusted time series
% B. Moving standard deviation and trends
% C. Variance scaling weights
plotVarianceAdjustment('raw-variance.eps', 'variance-trend.eps', 'variance-weights.eps');

% Subplots merged and edited in Adobe Illustrator CC 2021
% to produce final figure 'variance-adjustment.eps'


%% Supp. Table 1:

% This table did not rely on code, and was entered into Latex manually.


%% Supp. Table 2: SAM Latitudes in models

% This function requires that you first download the climate model output
% files for sea-level pressure that are detailed in the "Input Data" folder. 
% You should then add these files to the active Matlab path, and run lines
% 91-109 of the "runAnalysis.m" script in the "Analysis" folder. You can
% adjust these lines to only organize the SLP variables, as the temperature
% and precipitation datasets are not required for this plot.

models = parameters.models.all;   % Get the latitudes for all models
modelSAMLatitudes(models);        % Print Latex table to console


%% Supp. Table 3: PAGES2k Sites

% This table did not rely on code and was entered into Latex manually

